@@ -2,26 +2,28 @@
 package Plack::Test::Simple;
 
 use utf8;
+
 use Carp;
 use HTTP::Request;
 use HTTP::Response;
-use URI;
 use Moo;
-use Plack::Util;
 use Plack::Test::Simple::Transaction;
+use Plack::Util;
+use URI;
+
 use JSON qw(encode_json);
 
-our $VERSION = '0.000008'; # VERSION
-
+our $VERSION = '0.02'; # VERSION
 
 sub BUILDARGS {
     my ($class, @args) = @_;
 
-    unshift @args, 'psgi' if $args[0] && !$args[1];
+    @args = @args == 1 ? 'HASH' eq ref $args[0] ?
+        %{$args[0]} : ('psgi', @args) : @args;
+
     return {@args};
 }
 
-
 has request => (
     is      => 'rw',
     lazy    => 1,
@@ -34,7 +36,6 @@ sub _build_request {
     )
 }
 
-
 has psgi => (
     is     => 'rw',
     isa    => sub {
@@ -53,7 +54,6 @@ has psgi => (
     }
 );
 
-
 sub transaction {
     my ($self, $meth, $path, $cont) = @_;
 
@@ -75,15 +75,6 @@ sub transaction {
     return $trans;
 }
 
-
-
-
-
-
-
-
-
-
 sub AUTOLOAD {
     my ($self, @args)  = @_;
     my @cmds = split /_/, ($Plack::Test::Simple::AUTOLOAD =~ /.*::([^:]+)/)[0];
@@ -117,7 +108,7 @@ Plack::Test::Simple - Object-Oriented PSGI Application Testing
 
 =head1 VERSION
 
-version 0.000008
+version 0.02
 
 =head1 SYNOPSIS
 
